==> hive-apache-jdbc-0.13.1-9-sources.jar: io/trino/hive/jdbc/$internal/org/apache/thrift/meta_data/FieldValueMetaData.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements. See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership. The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License. You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package io.trino.hive.jdbc.$internal.org.apache.thrift.meta_data;

import io.trino.hive.jdbc.$internal.org.apache.thrift.protocol.TType;

/**
 * FieldValueMetaData and collection of subclasses to store metadata about
 * the value(s) of a field
 */
public class FieldValueMetaData implements java.io.Serializable {
  public final byte type;  

  private final boolean isTypedefType;
  private final String typedefName;
  private final boolean isBinary;

  public FieldValueMetaData(byte type, boolean binary) {
    this.type = type;
    this.isTypedefType = false;
    this.typedefName = null;
    this.isBinary = binary;
  }

  public FieldValueMetaData(byte type) {
    this(type, false);
  }

  public FieldValueMetaData(byte type, String typedefName) {
    this.type = type;
    this.isTypedefType = true;
    this.typedefName = typedefName;
    this.isBinary = false;
  }

  public boolean isTypedef() {
    return isTypedefType;
  }

  public String getTypedefName() {
    return typedefName;
  }

  public boolean isStruct() {
    return type == TType.STRUCT; 
  }

  public boolean isContainer() {
    return type == TType.LIST || type == TType.MAP || type == TType.SET;
  }

  public boolean isBinary() {
    return isBinary;
  }
}

==> hive-apache-jdbc-0.13.1-10-sources.jar: io/trino/hive/jdbc/$internal/org/apache/thrift/meta_data/FieldValueMetaData.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements. See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership. The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License. You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package io.trino.hive.jdbc.\$internal.org.apache.thrift.meta_data;

import io.trino.hive.jdbc.\$internal.org.apache.thrift.protocol.TType;

/**
 * FieldValueMetaData and collection of subclasses to store metadata about
 * the value(s) of a field
 */
public class FieldValueMetaData implements java.io.Serializable {
  public final byte type;  

  private final boolean isTypedefType;
  private final String typedefName;
  private final boolean isBinary;

  public FieldValueMetaData(byte type, boolean binary) {
    this.type = type;
    this.isTypedefType = false;
    this.typedefName = null;
    this.isBinary = binary;
  }

  public FieldValueMetaData(byte type) {
    this(type, false);
  }

  public FieldValueMetaData(byte type, String typedefName) {
    this.type = type;
    this.isTypedefType = true;
    this.typedefName = typedefName;
    this.isBinary = false;
  }

  public boolean isTypedef() {
    return isTypedefType;
  }

  public String getTypedefName() {
    return typedefName;
  }

  public boolean isStruct() {
    return type == TType.STRUCT; 
  }

  public boolean isContainer() {
    return type == TType.LIST || type == TType.MAP || type == TType.SET;
  }

  public boolean isBinary() {
    return isBinary;
  }
}
